OC.L10N.register(
    "federation",
    {
    "Server added to the list of trusted ownClouds" : "Server lagt til i listen av klarerte ownCloud'er",
    "Server is already in the list of trusted servers." : "Serveren er allerede i listen av klarerte servere.",
    "No ownCloud server found" : "Ingen ownCloud-server funnet",
    "Could not add server" : "Kunne ikke legge til server",
    "Federation" : "Sammenknytting",
    "ownCloud Federation allows you to connect with other trusted ownClouds to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "ownCloud-sammenknytting lar deg koble til andre klarerte ownCloud'er og utveksle brukerkatalogen. Dette vil for eksempel brukes til å fylle ut eksterne brukere for sammenknyttet deling automatisk.",
    "Add server automatically once a federated share was created successfully" : "Legg til server automatisk når en sammenknyttet deling er blitt opprettet",
    "Trusted ownCloud Servers" : "Klarerte ownCloud-servere",
    "+ Add ownCloud server" : "+ Ny ownCloud-server",
    "ownCloud Server" : "ownCloud-server"
},
"nplurals=2; plural=(n != 1);");
